#############################################################################
#
# MODULE:   	Grass Compilation
# AUTHOR(S):	Original author unknown - probably CERL
#		Markus Neteler - Germany/Italy - neteler@itc.it
#   	    	Justin Hickey - Thailand - jhickey@hpcc.nectec.or.th
#   	    	Huidae Cho - Korea - grass4u@gmail.com
#   	    	Eric G. Miller - egm2@jps.net
# PURPOSE:  	The source file for this Makefile is in src/CMD/head/head.in.
#		It is the top part of a file called make.rules which is used
#		for compiling all GRASS modules. This part of the file provides
#		make variables that are dependent on the results of the
#		configure script.
# COPYRIGHT:    (C) 2000 by the GRASS Development Team
#
#               This program is free software under the GNU General Public
#   	    	License (>=v2). Read the file COPYING that comes with GRASS
#   	    	for details.
#
#############################################################################

############################## Make Variables ###############################

CC                  = gcc
#FC                  = @F77@
CXX                 = c++
LEX                 = flex
YACC                = bison -y
PERL                = /usr/bin/perl
AR                  = ar
RANLIB              = ranlib
MKDIR               = mkdir -p
CHMOD               = chmod
INSTALL             = /usr/bin/install -c 
INSTALL_DATA        = ${INSTALL} -m 644

prefix              = /usr/lib
exec_prefix         = ${prefix}
ARCH                = sparc-unknown-linux-gnu
UNIX_BIN            = ${exec_prefix}/bin
INST_DIR            = ${prefix}/grass64

PLAT_OBJS           = 
STRIPFLAG           = 
CC_SEARCH_FLAGS     = -Wl,-rpath-link,${LIB_RUNTIME_DIR}
LD_SEARCH_FLAGS     = -Wl,-rpath-link,${LIB_RUNTIME_DIR}
LD_LIBRARY_PATH_VAR = LD_LIBRARY_PATH
LIB_RUNTIME_DIR     = $(ARCH_LIBDIR)

#static libs:
STLIB_LD            = ${AR} cr
STLIB_PREFIX        = lib
STLIB_SUFFIX        = .a

#shared libs
SHLIB_PREFIX        = lib
SHLIB_LD            = gcc -shared
SHLIB_LD_EXTRAS     = 
SHLIB_LD_FLAGS      = 
SHLIB_LD_LIBS       = ${LIBS}
SHLIB_CFLAGS        = -fPIC
SHLIB_SUFFIX        = .so
EXE                 = 


# GRASS dirs
GRASS_HOME          = /build/buildd/grass-6.4.0~rc5
RUN_GISBASE         = /build/buildd/grass-6.4.0~rc5/dist.sparc-unknown-linux-gnu
RUN_GISRC           = ${ARCH_DISTDIR}/demolocation/.grassrc${GRASS_VERSION_MAJOR}${GRASS_VERSION_MINOR}

DEFAULT_DATABASE    =
DEFAULT_LOCATION    =

CPPFLAGS            = 
CFLAGS1             = -Wall -g -O 
CXXFLAGS1           = -g -O2
INCLUDE_DIRS        = 

COMPILE_FLAGS       = $(CPPFLAGS) $(CFLAGS1) $(INCLUDE_DIRS)
COMPILE_FLAGS_CXX   = $(CPPFLAGS) $(CXXFLAGS1) $(INCLUDE_DIRS)
LINK_FLAGS          = -Wl,-Bsymbolic-functions -Wl,--export-dynamic

DLLIB               = -ldl
XCFLAGS             = 
XMINC               = 
XLIBPATH            = 
XLIB                =  -lSM -lICE -lX11
XTLIB               = -lXt
XMLIB               =  -lXm 
XEXTRALIBS          = 
USE_X11             = 1

COMPATLIB           = -lbsd-compat
CURSES              = -lncurses $(COMPATLIB)
USE_CURSES          = 1
MATHLIB             = -lm 
XDRLIB              =     -lz 
ICONVLIB            = 
INTLLIB             = 
SOCKLIB             = 

#ZLIB:
ZLIB                =    -lz 
ZLIBINCPATH         = 
ZLIBLIBPATH         = 

#DBM:
#DBMINCPATH          = @DBMINCPATH@
#DBMLIBPATH          = @DBMLIBPATH@
#DBMLIB              = @DBMLIB@
DBMIEXTRALIB        = 

#readline
READLINEINCPATH     = 
READLINELIBPATH     = 
READLINELIB         =  -lreadline 
HISTORYLIB          =  -lhistory 

#PostgreSQL:
PQINCPATH           =  -I/usr/include/postgresql
PQLIBPATH           = 
PQLIB               =  -lpq 

#MySQL:
MYSQLINCPATH        =  -I/usr/include/mysql
MYSQLLIBPATH        = 
MYSQLLIB            =  -lmysqlclient 
MYSQLDLIB            = 

#SQLite:
SQLITEINCPATH        = 
SQLITELIBPATH        = 
SQLITELIB            =  -lsqlite3 

#FFMPEG
FFMPEGINCPATH        = 
FFMPEGLIBPATH        = 
FFMPEGLIB            = 

#ODBC:
ODBCINC             = 
ODBCLIB             =  -lodbc 

#Image formats:
PNGINC              = 
PNGLIB              =  -lpng  -lz  -lm
USE_PNG             = 1

JPEGINCPATH         = 
JPEGLIBPATH         = 
JPEGLIB             =  -ljpeg 

TIFFINCPATH         = 
TIFFLIBPATH         = 
TIFFLIB             =  -ltiff 

#openGL files for NVIZ/r3.showdspf
OPENGLINC           = 
OPENGLWINC          = 
OPENGLLIB           =   -lGL 
OPENGLULIB          =   -lGLU 
OPENGLWM            = 
#USE_GLWM            = @USE_GLWM@
OPENGL_X11          = 1
OPENGL_AQUA         = 
OPENGL_WINDOWS      = 

#tcl/tk stuff
TCLINCDIR           =  -I/usr/include/tcl
TKINCDIR            =  -I/usr/include/tcl
TCLTKLIBPATH        = 
TCLTKLIBS           =  -ltk -lm  -ltcl -lm
TCLVERSION          = 8.4
# set from configure when 64bit TclTk Aqua becomes possible on OSX
TCLTKAQUA_IS64BIT    = 

#FFTW:
FFTWINC             = 
FFTWLIB             =  -lfftw3 -lm

#LAPACK/BLAS stuff for gmath lib:
BLASLIB             = 
BLASINC				= 
LAPACKLIB           = 
LAPACKINC			= 

#GDAL/OGR
GDALLIBS            = -L/usr/lib -lgdal1.5.0
GDALCFLAGS          = -I/usr/include/gdal
USE_GDAL            = 1
USE_OGR             = 1

#FreeType:
FTINC               =  -I/usr/include/freetype2
FTLIB               =  -lfreetype 

#PROJ.4:
PROJINC             =  $(GDALCFLAGS)
PROJLIB             =  -lproj 
NAD2BIN             = /usr/bin/nad2bin
PROJSHARE           = /usr/share/proj

#OPENDWG:
OPENDWGINCPATH      = 
OPENDWGLIBPATH      = 
OPENDWGLIB          = 
USE_OPENDWG         = 

#cairo
CAIROINC            = -D_REENTRANT -I/usr/include/cairo -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/directfb -I/usr/include/libpng12  
CAIROLIB            = -lfreetype -lfontconfig -lXrender -lcairo -lX11    
USE_CAIRO           = 1

#Python
PYTHONINC           = -I/usr/include/python2.6 -I/usr/include/python2.6
PYTHONCFLAGS        = -I/usr/include/python2.6 -I/usr/include/python2.6 -fno-strict-aliasing -DNDEBUG -g -fwrapv -O2 -Wall -Wstrict-prototypes
PYTHONLDFLAGS       = -L/usr/lib/python2.6/config -lpthread -ldl -lutil -lm -lpython2.6
SWIG                = /usr/bin/swig
USE_PYTHON          = 1

#wxWidgets
WXVERSION           = 2.8.10
WXWIDGETSCXXFLAGS   = -I/usr/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/include/wx-2.8 -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D__WXGTK__ -pthread
WXWIDGETSCPPFLAGS   = -I/usr/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/include/wx-2.8 -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D__WXGTK__
WXWIDGETSLIB        = -pthread -Wl,-Bsymbolic-functions  -lwx_gtk2u_richtext-2.8 -lwx_gtk2u_aui-2.8 -lwx_gtk2u_xrc-2.8 -lwx_gtk2u_qa-2.8 -lwx_gtk2u_html-2.8 -lwx_gtk2u_adv-2.8 -lwx_gtk2u_core-2.8 -lwx_baseu_xml-2.8 -lwx_baseu_net-2.8 -lwx_baseu-2.8 
USE_WXWIDGETS       = 1
# set from configure when 64bit wxWidgets becomes possible on OSX
WX_ISOSX64BIT       = 

#regex
REGEXINCPATH        = 
REGEXLIBPATH        = 
REGEXLIB            =  
USE_REGEX           = 1

#i18N
HAVE_NLS            = 1

#Large File Support (LFS)
USE_LARGEFILES      = 1

#BSD sockets
HAVE_SOCKET         = 1

MINGW		    = 
MACOSX_APP	    = 

# Cross compilation
CROSS_COMPILING =  
